#[repr(C)]pub struct BytecodeBlock {
pub startpc: i32,
pub finishpc: i32,
}Fields
startpc: i32‘start’ and ‘finish’ define an inclusive range of instructions which belong to the block
finishpc: i32Trait Implementations
Sourceimpl Clone for BytecodeBlock
impl Clone for BytecodeBlock
Sourcefn clone(&self) -> BytecodeBlock
fn clone(&self) -> BytecodeBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BytecodeBlock
Sourceimpl Debug for BytecodeBlock
impl Debug for BytecodeBlock
Sourceimpl Default for BytecodeBlock
impl Default for BytecodeBlock
impl Eq for BytecodeBlock
Sourceimpl Hash for BytecodeBlock
impl Hash for BytecodeBlock
Sourceimpl PartialEq for BytecodeBlock
impl PartialEq for BytecodeBlock
Sourcefn eq(&self, other: &BytecodeBlock) -> bool
fn eq(&self, other: &BytecodeBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BytecodeBlock