#[repr(C)]pub struct CompilationOptions {
pub flags: u32,
pub hooks: HostIrHooks,
pub userdata_types: *const *const c_char,
pub record_counters: bool,
pub nop_padding: bool,
}Fields
flags: u32hooks: HostIrHooksuserdata_types: *const *const c_charnull-terminated array of userdata types names that might have custom lowering
record_counters: boolnop_padding: boolWhen true, random NOP sleds are inserted between blocks to make intra-function gadget offsets unpredictable.