#[repr(C)]pub struct Set {
pub base: u32,
pub free: u32,
pub temp: u32,
pub defs: [u32; 32],
}Fields
base: u32which registers are in the set that the allocator manages (initialized at construction)
free: u32which subset of initial set is free
temp: u32which subset of initial set is allocated as temporary
defs: [u32; 32]which instruction is defining which register (for spilling); only valid if not free and not temp