Module type_aliases

Module type_aliases 

Modules

allocation_callback
annotator_fn
exit_sync_args_a_64
exit_sync_args_x_64
gate_fn
host_userdata_access_handler
host_userdata_metamethod_bytecode_type
host_userdata_metamethod_handler
host_userdata_namecall_handler
host_userdata_operation_bytecode_type
host_vector_access_handler
host_vector_namecall_handler
host_vector_operation_bytecode_type
instruction_ir_builder
instruction_ir_translation
ir_ops
lua_state
lua_State as seen by CodeGen — the VM’s own type, not an opaque twin (CodeGen executes against real VM state).
luau_fast_function
mem
module_id
native_proto_exec_data_ptr
perf_log_fn
unique_shared_code_gen_context
Native-only type alias for a unique pointer to SharedCodeGenContext with a custom deleter. This type is used to manage the lifecycle of shared code generation contexts in native builds. Since Rust’s Box<T> does not support custom deleters without a custom allocator, and this type is native-only, we represent it as a raw pointer with manual lifecycle management by downstream code.
unw_add_find_dynamic_unwind_sections_t
userdata_remapper_callback