#[repr(C)]pub struct IrBlock {
pub kind: IrBlockKind,
pub flags: u8,
pub use_count: u16,
pub start: u32,
pub finish: u32,
pub sortkey: u32,
pub chainkey: u32,
pub expected_next_block: u32,
pub startpc: u32,
pub label: Label,
}Fields
kind: IrBlockKindflags: u8use_count: u16start: u32‘start’ and ‘finish’ define an inclusive range of instructions which belong to this block inside the function When block has been constructed, ‘finish’ always points to the first and only terminating instruction
finish: u32sortkey: u32chainkey: u32expected_next_block: u32startpc: u32Bytecode PC position at which the block was generated
label: LabelTrait Implementations
impl Copy for IrBlock
impl Eq for IrBlock
impl StructuralPartialEq for IrBlock