Modules
- allocation_
callback - annotator_
fn - exit_
sync_ args_ a_ 64 - exit_
sync_ args_ x_ 64 - gate_fn
- host_
userdata_ access_ handler - host_
userdata_ metamethod_ bytecode_ type - host_
userdata_ metamethod_ handler - host_
userdata_ namecall_ handler - host_
userdata_ operation_ bytecode_ type - host_
vector_ access_ handler - host_
vector_ namecall_ handler - host_
vector_ operation_ bytecode_ type - instruction_
ir_ builder - instruction_
ir_ translation - ir_ops
- lua_
state lua_Stateas seen by CodeGen — the VM’s own type, not an opaque twin (CodeGen executes against real VM state).- luau_
fast_ function - mem
- module_
id - native_
proto_ exec_ data_ ptr - perf_
log_ fn - unique_
shared_ code_ gen_ context - Native-only type alias for a unique pointer to
SharedCodeGenContextwith a custom deleter. This type is used to manage the lifecycle of shared code generation contexts in native builds. Since Rust’sBox<T>does not support custom deleters without a custom allocator, and this type is native-only, we represent it as a raw pointer with manual lifecycle management by downstream code. - unw_
add_ find_ dynamic_ unwind_ sections_ t - userdata_
remapper_ callback